@@ -1,7 +1,7 @@
 package App::wdq;
 use v5.14;
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.1.0';
 
 1;
 __END__
@@ -29,13 +29,21 @@ Either install from CPAN with all dependencies:
 or install dependencies as prebuild packages (for instance Debian) and copy
 the `wdq` script at some place in your C<$PATH>:
 
-  apt-get install libhttp-tiny-perl libjson-perl
+  apt-get install libhttp-tiny-perl librdf-query-perl
   wget https://github.com/nichtich/wdq/raw/master/bin/wdq
   chmod +x wdq
 
 =head1 USAGE
  
   wdq --help
+  
+=head1 EXAMPLES
+
+  # get all parts of the solar system
+  wdq -q '{ ?c wdt:P361 wd:Q544 }'
+
+  # execute query and return tab-separated values
+  wdq -f tsv < query
 
 =head1 COPYRIGHT AND LICENSE
 
